==> vtk-v4.0.2.zip: vtk-v4.0.2/Parallel/vtkPSphereSource.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkPSphereSource.h
  Language:  C++
  Date:      $Date$
  Version:   $Revision$


Copyright (c) 1993-2001 Ken Martin, Will Schroeder, Bill Lorensen 
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither name of Ken Martin, Will Schroeder, or Bill Lorensen nor the names
   of any contributors may be used to endorse or promote products derived
   from this software without specific prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
// .NAME vtkPSphereSource - sphere source that supports pieces

#ifndef __vtkPSphereSource_h
#define __vtkPSphereSource_h

#include "vtkSphereSource.h"

class VTK_PARALLEL_EXPORT vtkPSphereSource : public vtkSphereSource
{
public:
  vtkTypeMacro(vtkPSphereSource,vtkSphereSource);

  // Description:
  // Construct sphere with radius=0.5 and default resolution 8 in both Phi
  // and Theta directions. Theta ranges from (0,360) and phi (0,180) degrees.
  static vtkPSphereSource *New();

  // Description:
  // Get the estimated memory size in 1024 bytes
  unsigned long GetEstimatedMemorySize();
  
protected:
  vtkPSphereSource() {};
  ~vtkPSphereSource() {};

  void Execute();
private:
  vtkPSphereSource(const vtkPSphereSource&);  // Not implemented.
  void operator=(const vtkPSphereSource&);  // Not implemented.
};

#endif

==> vtk-v4.2.6.zip: vtk-v4.2.6/Parallel/vtkPSphereSource.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkPSphereSource.h
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

  Copyright (c) 1993-2002 Ken Martin, Will Schroeder, Bill Lorensen 
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even 
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkPSphereSource - sphere source that supports pieces

#ifndef __vtkPSphereSource_h
#define __vtkPSphereSource_h

#include "vtkSphereSource.h"

class VTK_PARALLEL_EXPORT vtkPSphereSource : public vtkSphereSource
{
public:
  vtkTypeRevisionMacro(vtkPSphereSource,vtkSphereSource);

  // Description:
  // Construct sphere with radius=0.5 and default resolution 8 in both Phi
  // and Theta directions. Theta ranges from (0,360) and phi (0,180) degrees.
  static vtkPSphereSource *New();
  virtual void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Get the estimated memory size in 1024 bytes
  unsigned long GetEstimatedMemorySize();
  
protected:
  vtkPSphereSource() {};
  ~vtkPSphereSource() {};

  void Execute();
private:
  vtkPSphereSource(const vtkPSphereSource&);  // Not implemented.
  void operator=(const vtkPSphereSource&);  // Not implemented.
};

#endif
